#

##

##

##

##

##

    	genome
    		# aggregates
    		# balance sheets
    		# squeezes

    	summary

    		These are aggregations (like balance sheets) of the
    		activity summarized, whereby preceeding genes and
    		sequences are not necessary for petitioning new
    		sequences.

    		Every 100 blocks or so, a squash is generated
    		that aggregates everything before the squash.

    			Therefore, new businesses can start voting
    			without having to retrieve the entire
    			history of the universe.

    	structure

    		DB:"genome 00000000000000000000000000000841":
    			collection: map [{
    				"previous": 1,
    				"genes": [ 9, 17 ]
    			}]

    			collection: mottos [{
    				"sequences": {
    					"per gene": 8
    				},
    				"petitions": {
    					"voting": {
    						">= fraction necessary": "1/2"
    					},
    					"fees": {
    						"change motto": 10,

    						"promote to voter": 10,
    						"demote to voter": 10,

    						"send escrow": 10,
    						"receive escrow": 10
    					}
    				},
    				"voters": {
    					"minimum amount": 100000
    				}
    			}]

    			collection: voters [{
    				"address": "",
    				"amount": 12340
    			},{
    				"address": "",
    				"amount": 12340
    			}]

    			collection: escrow [{
    				"address": {
    					"from": "",
    					"to": ""
    				},
    				"amount": 12340
    			},{
    				"address": {
    					"from": "",
    					"to": ""
    				},
    				"amount": 12340
    			}]

    	physics

    		gestures per scene = 100

    	objectives ranked

    	possibilities

    		[ ] squeezes happen every few scenes